# swagger-java-client

## Requirements

Building the API client library requires [Maven](https://maven.apache.org/) to be installed.

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn deploy
```

Refer to the [official documentation](https://maven.apache.org/plugins/maven-deploy-plugin/usage.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
    <groupId>io.swagger</groupId>
    <artifactId>swagger-java-client</artifactId>
    <version>1.0.0</version>
    <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "io.swagger:swagger-java-client:1.0.0"
```

### Others

At first generate the JAR by executing:

    mvn package

Then manually install the following JARs:

* target/swagger-java-client-1.0.0.jar
* target/lib/*.jar

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.AccountApi;

import java.io.File;
import java.util.*;

public class AccountApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();
        
        // Configure API key authorization: apiKeyQuery
        ApiKeyAuth apiKeyQuery = (ApiKeyAuth) defaultClient.getAuthentication("apiKeyQuery");
        apiKeyQuery.setApiKey("YOUR API KEY");
        // Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
        //apiKeyQuery.setApiKeyPrefix("Token");

        AccountApi apiInstance = new AccountApi();
        Integer details = 1; // Integer | level of information returned
        try {
            Account result = apiInstance.accountInfoGet(details);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling AccountApi#accountInfoGet");
            e.printStackTrace();
        }
    }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://api.browshot.com/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**accountInfoGet**](docs/AccountApi.md#accountInfoGet) | **GET** /account/info | Get information about your account.
*BatchApi* | [**batchCeatePost**](docs/BatchApi.md#batchCeatePost) | **POST** /batch/ceate | Requests thousands of screenshtos at once
*BatchApi* | [**batchInfoGet**](docs/BatchApi.md#batchInfoGet) | **GET** /batch/info | Get the batch status
*BrowserApi* | [**browserInfoGet**](docs/BrowserApi.md#browserInfoGet) | **GET** /browser/info | Get information about a browser
*BrowserApi* | [**browserListGet**](docs/BrowserApi.md#browserListGet) | **GET** /browser/list | Get all browsers
*InstanceApi* | [**instanceInfoGet**](docs/InstanceApi.md#instanceInfoGet) | **GET** /instance/info | Get information about an instance
*InstanceApi* | [**instanceListGet**](docs/InstanceApi.md#instanceListGet) | **GET** /instance/list | Get all instances
*ScreenshotApi* | [**screenshotCreateGet**](docs/ScreenshotApi.md#screenshotCreateGet) | **GET** /screenshot/create | Request a screenshot
*ScreenshotApi* | [**screenshotDeleteGet**](docs/ScreenshotApi.md#screenshotDeleteGet) | **GET** /screenshot/delete | Delete screenshot data
*ScreenshotApi* | [**screenshotHostGet**](docs/ScreenshotApi.md#screenshotHostGet) | **GET** /screenshot/host | Host thumbnails on your own S3 account or on Browshot.
*ScreenshotApi* | [**screenshotHtmlGet**](docs/ScreenshotApi.md#screenshotHtmlGet) | **GET** /screenshot/html | Get the HTML code
*ScreenshotApi* | [**screenshotInfoGet**](docs/ScreenshotApi.md#screenshotInfoGet) | **GET** /screenshot/info | Query screenshot status
*ScreenshotApi* | [**screenshotListGet**](docs/ScreenshotApi.md#screenshotListGet) | **GET** /screenshot/list | Get information about the last 100 screenshots requested.
*ScreenshotApi* | [**screenshotMultipleGet**](docs/ScreenshotApi.md#screenshotMultipleGet) | **GET** /screenshot/multiple | Request multiple screenshots
*ScreenshotApi* | [**screenshotSearchGet**](docs/ScreenshotApi.md#screenshotSearchGet) | **GET** /screenshot/search | Search for screenshots of a specific URL.
*ScreenshotApi* | [**screenshotShareGet**](docs/ScreenshotApi.md#screenshotShareGet) | **GET** /screenshot/share | Share a screenshot
*ScreenshotApi* | [**screenshotThumbnailGet**](docs/ScreenshotApi.md#screenshotThumbnailGet) | **GET** /screenshot/thumbnail | Retrieve a thumbnail image


## Documentation for Models

 - [Account](docs/Account.md)
 - [AccountError](docs/AccountError.md)
 - [Batch](docs/Batch.md)
 - [BatchError](docs/BatchError.md)
 - [Browser](docs/Browser.md)
 - [BrowserError](docs/BrowserError.md)
 - [BrowserList](docs/BrowserList.md)
 - [Instance](docs/Instance.md)
 - [InstanceError](docs/InstanceError.md)
 - [InstanceList](docs/InstanceList.md)
 - [Screenshot](docs/Screenshot.md)
 - [ScreenshotError](docs/ScreenshotError.md)
 - [ScreenshotHost](docs/ScreenshotHost.md)
 - [ScreenshotInfoError](docs/ScreenshotInfoError.md)
 - [ScreenshotList](docs/ScreenshotList.md)
 - [ScreenshotShort](docs/ScreenshotShort.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### apiKeyQuery

- **Type**: API key
- **API key parameter name**: key
- **Location**: URL query string


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

support@browshot.com

